Version 1.1.3
-------------

-   Fix: If channel is closed, reconnect

Version 1.1.2
-------------

-   Fix: Slow down retry rate

Version 1.1.1
-------------

-   Fix: Retry when connection to broker fails

Version 1.1.0
-------------

-   Chore: Added typehints

Version 1.0.0
-------------

-   Initial public release
